# Generated by roxygen2: do not edit by hand

export(cor_bin)
export(cor_cont)
export(est_mixture)
importFrom(stats,cov)
importFrom(stats,dnorm)
importFrom(stats,optim)
importFrom(stats,optimize)
importFrom(stats,qchisq)
importFrom(stats,qnorm)
importFrom(stats,sd)
