#' Example Data: Binary Variables
#'
#' Simulated dataset for testing the \code{cor_bin()} function.
#'
#' @format A data frame with 3 columns:
#' \describe{
#'   \item{ni}{Sample size per study}
#'   \item{xi}{Count of first binary variable}
#'   \item{yi}{Count of second binary variable}
#' }
#' @usage data(bin_example)
#' @keywords datasets
"bin_example"