#' Example Data: Continuous Variables
#'
#' Simulated dataset for testing the \code{cor_cont()} function.
#'
#' @format A data frame with 5 columns:
#' \describe{
#'   \item{Sample_Size}{Sample size for each study.}
#'   \item{Mean_X}{Sample mean of variable X.}
#'   \item{Mean_Y}{Sample mean of variable Y.}
#'   \item{Variance_X}{Sample variance of variable X.}
#'   \item{Variance_Y}{Sample variance of variable Y.}
#' }
#' @usage data(cont_example)
#' @keywords datasets
"cont_example"
