% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cont_example.R
\docType{data}
\name{cont_example}
\alias{cont_example}
\title{Example Data: Continuous Variables}
\format{
A data frame with 5 columns:
\describe{
  \item{Sample_Size}{Sample size for each study.}
  \item{Mean_X}{Sample mean of variable X.}
  \item{Mean_Y}{Sample mean of variable Y.}
  \item{Variance_X}{Sample variance of variable X.}
  \item{Variance_Y}{Sample variance of variable Y.}
}
}
\usage{
data(cont_example)
}
\description{
Simulated dataset for testing the \code{cor_cont()} function.
}
\keyword{datasets}
