% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bin_example.R
\docType{data}
\name{bin_example}
\alias{bin_example}
\title{Example Data: Binary Variables}
\format{
A data frame with 3 columns:
\describe{
  \item{ni}{Sample size per study}
  \item{xi}{Count of first binary variable}
  \item{yi}{Count of second binary variable}
}
}
\usage{
data(bin_example)
}
\description{
Simulated dataset for testing the \code{cor_bin()} function.
}
\keyword{datasets}
